==> tine20-allinone_2020.03.4.tar.bz2: Crm/js/Crm-lang-pl_PL-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Crm **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Crm'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2012-04-02 13:31+0000\nLast-Translator: Cornelius Weiss <c.weiss@metaways.de>\nLanguage-Team: Polish (Poland) (http://www.transifex.com/tine20/tine20/language/pl_PL/)\nLanguage: pl_PL\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=4; plural=(n==1 ? 0 : (n%10>=2 && n%10<=4) && (n%100<12 || n%100>14) ? 1 : n!=1 && (n%10>=0 && n%10<=1) || (n%10>=5 && n%10<=9) || (n%100>=12 && n%100<=14) ? 2 : 3);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "All leads"
: ""

, "Default Lead List"
: ""

, "The default list for new leads"
: ""

, "Get Notification E-mails"
: ""

, "The level of actions you want to be notified about."
: ""

, "Send Notifications e-mails for own actions"
: ""

, "Get notifications e-mails for actions you did yourself"
: ""

, "Send Notifications e-mails to responsible"
: ""

, "Get notifications e-mails for action to responsible"
: ""

, "Send Notifications e-mails to customer"
: ""

, "Get notifications e-mails for action to customer"
: ""

, "Send Notifications e-mails to partner"
: ""

, "Get notifications e-mails for action to partner"
: ""

, "Default Favorite"
: ""

, "The default favorite which is loaded on crm startup"
: ""

, "New Lead"
: ""

, "Tags"
: ""

, "Lead name"
: ""

, "Responsible"
: ""

, "Partner"
: ""

, "Customer"
: ""

, "Leadstate"
: ""

, "Leadtype"
: ""

, "Leadsource"
: ""

, "Probability"
: ""

, "Turnover"
: ""

, "Estimated end"
: ""

, "Probable Turnover"
: ""

, "Resubmission Date"
: ""

, "Import leads"
: ""

, "Contact"
: ""

, "CRM Role"
: ""

, "Tasks"
: ""

, "No Tasks to display"
: ""

, "Summary"
: ""

, "Add a task..."
: ""

, "Due Date"
: ""

, "Priority"
: ""

, "Percent"
: ""

, "Status"
: ""

, "Organizer"
: ""

, "Add new {0}"
: ""

, "Unlink {0}"
: ""

, "Unlink selected {0}"
: ""

, "Edit {0}"
: ""

, "Edit selected {0}"
: ""

, "Please choose the Lead to add the contacts to"
: ""

, "Please select the attenders' role"
: ""

, "Lead, Leads"
: [
  ""
 ,""
 ,""
 ,""

]
, "Select Lead"
: ""

, "Role"
: ""

, "Select Role"
: ""

, "Adding {0} contacts to lead"
: ""

, "Phone"
: ""

, "Mobile"
: ""

, "Fax"
: ""

, "E-Mail"
: ""

, "Web"
: ""

, "Street"
: ""

, "Postalcode"
: ""

, "City"
: ""

, "Start"
: ""

, "Change type to Customer"
: ""

, "Change type to Responsible"
: ""

, "Change type to Partner"
: ""

, "Change contact type"
: ""

, "Search for Contacts to add ..."
: ""

, "Name"
: ""

, "Address"
: ""

, "Data"
: ""

, "Cellphone"
: ""

, "End"
: ""

, "You do not have the run right for the Tasks application or it is not activated."
: ""

, "Products"
: ""

, "You do not have the run right for the Sales application or it is not activated."
: ""

, "Enter lead name"
: ""

, "Expected turnover"
: ""

, "Description"
: ""

, "Enter description"
: ""

, "lead list, lead lists"
: [
  ""
 ,""
 ,""
 ,""

]
, "lead lists"
: ""

, "Quick Search"
: ""

, "Last Modified Time"
: ""

, "Last Modified By"
: ""

, "Creation Time"
: ""

, "Created By"
: ""

, "X Lead"
: ""

, "Archived"
: ""

, "Product"
: ""

, "Price"
: ""

, "Quantity"
: ""

, "Search for Products to add ..."
: ""

, "All leads I have read grants for"
: ""

, "Last modified by me"
: ""

, "All leads that I have last modified"
: ""

, "My leads"
: ""

, "All leads that I am responsible for"
: ""

, "Leads with overdue tasks"
: ""

, "Lead States Available"
: ""

, "Possible lead status, with their associated turnover probabilities. If a status is flagged, leads with this status are treated as closed."
: ""

, "open"
: ""

, "contacted"
: ""

, "waiting for feedback"
: ""

, "quote sent"
: ""

, "accepted"
: ""

, "lost"
: ""

, "Lead Sources Available"
: ""

, "Possible lead sources. If a source is flagged as archived, leads of this source are treated as closed."
: ""

, "Lead Types Available"
: ""

, "Possible lead types."
: ""

, "Reseller"
: ""

, "Enabled Features"
: ""

, "Enabled Features in CRM Application."
: ""

, "Lead Import"
: ""

, "Add new task on lead import"
: ""

, "Automatically creates a task for the responsible person if a new lead is imported."
: ""

, "Send notification e-mail on lead import"
: ""

, "Sends an e-mail to all responsible persons for the imported leads."
: ""

, "Lead duplicate check fields"
: ""

, "These fields are checked when a new lead is created. If a record with the same data in the fields is found, a duplicate exception is thrown."
: ""

, "State"
: ""

, "Source"
: ""

, "Scheduled end"
: ""

, "Folder"
: ""

, "Updated by"
: ""

, "Updated Fields:"
: ""

, "'%s' changed from '%s' to '%s'."
: ""

, "Lead %s has been changed"
: ""

, "Lead %s has been deleted"
: ""

, "Lead %s has been created"
: ""

, "Task"
: ""

, "Lead Data"
: ""

, "End Scheduled"
: ""

, "Contacts"
: ""

, "Telephone"
: ""

, "Email"
: ""

, "low"
: ""

, "normal"
: ""

, "high"
: ""

, "urgent"
: ""

, "Lead CSV import"
: ""

, "Import list (###CURRENTDATE###)"
: ""

, "Leads imported on ###CURRENTDATE### at ###CURRENTTIME### by ###USERFULLNAME###"
: ""

, "Edit new lead"
: ""

, "The following leads have just been imported into lead list %s"
: ""

, "%s new leads have been imported"
: ""

, "manage shared lead folders"
: ""

, "Create new shared lead folders"
: ""

, "manage shared leads favorites"
: ""

, "Create or update shared leads favorites"
: ""

, "Lead"
: ""

, "lead list"
: ""

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;

==> tine20-allinone_2021.12.1.tar.bz2: Crm/js/Crm-lang-pl_PL-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Crm **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Crm'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2020-05-11 11:49+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Polish (Poland) (http://www.transifex.com/tine20/tine20/language/pl_PL/)\nLanguage: pl_PL\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=4; plural=(n==1 ? 0 : (n%10>=2 && n%10<=4) && (n%100<12 || n%100>14) ? 1 : n!=1 && (n%10>=0 && n%10<=1) || (n%10>=5 && n%10<=9) || (n%100>=12 && n%100<=14) ? 2 : 3);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Customer"
: ""

, "Partner"
: ""

, "Phone"
: ""

, "Mobile"
: ""

, "Fax"
: ""

, "E-Mail"
: ""

, "Web"
: ""

, "Street"
: ""

, "Postalcode"
: ""

, "City"
: ""

, "Status"
: ""

, "Start"
: ""

, "Estimated end"
: ""

, "Leadtype"
: ""

, "Leadsource"
: ""

, "Tags"
: ""

, "Lead name"
: ""

, "Responsible"
: ""

, "Leadstate"
: ""

, "Probability"
: ""

, "Turnover"
: ""

, "End"
: ""

, "Probable Turnover"
: ""

, "Resubmission Date"
: ""

, "Import leads"
: ""

, "Add new {0}"
: ""

, "Unlink {0}"
: ""

, "Unlink selected {0}"
: ""

, "Edit {0}"
: ""

, "Edit selected {0}"
: ""

, "New Lead"
: ""

, "Products"
: ""

, "Product"
: ""

, "Description"
: ""

, "Price"
: ""

, "Quantity"
: ""

, "Search for Products to add ..."
: ""

, "1"
: ""

, "Notifications are disabled"
: ""

, "Send Notification?"
: ""

, "Changes to this lead might send notifications. Press the button \"Notifcation are enabled\" to switch to \"Notification are disabled\""
: ""

, "Tasks"
: ""

, "You do not have the run right for the Tasks application or it is not activated."
: ""

, "You do not have the run right for the Sales application or it is not activated."
: ""

, "Lead, Leads"
: [
  ""
 ,""
 ,""
 ,""

]
, "Enter lead name"
: ""

, "Expected turnover"
: ""

, "Enter description"
: ""

, "lead list, lead lists"
: [
  ""
 ,""
 ,""
 ,""

]
, "lead lists"
: ""

, "Quick Search"
: ""

, "Last Modified Time"
: ""

, "Last Modified By"
: ""

, "Creation Time"
: ""

, "Created By"
: ""

, "X Lead"
: ""

, "read-only"
: ""

, "Archived"
: ""

, "Contact"
: ""

, "CRM Role"
: ""

, "Change type to Customer"
: ""

, "Change type to Responsible"
: ""

, "Change type to Partner"
: ""

, "Change contact type"
: ""

, "Search for Contacts to add ..."
: ""

, "Name"
: ""

, "Address"
: ""

, "Data"
: ""

, "Cellphone"
: ""

, "Role"
: ""

, "Please choose the Lead to add the contacts to"
: ""

, "Please select the attenders' role"
: ""

, "Select Lead"
: ""

, "Select Role"
: ""

, "Adding {0} contacts to lead"
: ""

, "No Tasks to display"
: ""

, "Summary"
: ""

, "Add a task..."
: ""

, "Due Date"
: ""

, "Priority"
: ""

, "Percent"
: ""

, "Organizer"
: ""

, "All leads"
: ""

, "Default Lead List"
: ""

, "The default list for new leads"
: ""

, "Get Notification E-mails"
: ""

, "The level of actions you want to be notified about."
: ""

, "Send Notifications e-mails for own actions"
: ""

, "Get notifications e-mails for actions you did yourself"
: ""

, "Default Favorite"
: ""

, "The default favorite which is loaded on crm startup"
: ""

, "controls sending notification of Leads"
: ""

, "send notification)description"
: ""

, "send notification to all access container"
: ""

, "send notification to responsible"
: ""

, "send notification to responsible)description"
: ""

, "send notification to customer"
: ""

, "send notification to partner"
: ""

, "Lead States Available"
: ""

, "Possible lead status, with their associated turnover probabilities. If a status is flagged, leads with this status are treated as closed."
: ""

, "open"
: ""

, "contacted"
: ""

, "waiting for feedback"
: ""

, "quote sent"
: ""

, "accepted"
: ""

, "lost"
: ""

, "Lead Sources Available"
: ""

, "Possible lead sources. If a source is flagged as archived, leads of this source are treated as closed."
: ""

, "Lead Types Available"
: ""

, "Possible lead types."
: ""

, "Reseller"
: ""

, "Enabled Features"
: ""

, "Enabled Features in CRM Application."
: ""

, "Lead Import"
: ""

, "Lead Notification Confirmation"
: ""

, "Add new task on lead import"
: ""

, "Automatically creates a task for the responsible person if a new lead is imported."
: ""

, "Send notification e-mail on lead import"
: ""

, "Sends an e-mail to all responsible persons for the imported leads."
: ""

, "Lead duplicate check fields"
: ""

, "These fields are checked when a new lead is created. If a record with the same data in the fields is found, a duplicate exception is thrown."
: ""

, "Lead Data"
: ""

, "End Scheduled"
: ""

, "Contacts"
: ""

, "Telephone"
: ""

, "Email"
: ""

, "low"
: ""

, "normal"
: ""

, "high"
: ""

, "urgent"
: ""

, "CSV all data"
: ""

, "Lead CSV import"
: ""

, "Import list (###CURRENTDATE###)"
: ""

, "Leads imported on ###CURRENTDATE### at ###CURRENTTIME### by ###USERFULLNAME###"
: ""

, "Edit new lead"
: ""

, "The following leads have just been imported into lead list %s"
: ""

, "%s new leads have been imported"
: ""

, "GENDER_Lead"
: ""

, "Show Closed"
: ""

, "Task"
: ""

, "State"
: ""

, "Source"
: ""

, "Scheduled end"
: ""

, "Folder"
: ""

, "Updated by"
: ""

, "Updated Fields:"
: ""

, "'%s' changed from '%s' to '%s'."
: ""

, "Lead %s has been changed"
: ""

, "Lead %s has been deleted"
: ""

, "Lead %s has been created"
: ""

, "This Lead state is set to read-only therefore updating this Lead is not possible."
: ""

, "All leads I have read grants for"
: ""

, "Last modified by me"
: ""

, "All leads that I have last modified"
: ""

, "My leads"
: ""

, "All leads that I am responsible for"
: ""

, "Leads with overdue tasks"
: ""

, "manage shared lead folders"
: ""

, "Create new shared lead folders"
: ""

, "manage shared leads favorites"
: ""

, "Create or update shared leads favorites"
: ""

, "Lead"
: ""

, "lead list"
: ""

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;
